@@ -3,26 +3,22 @@
 # Purpose: Provides artwork for Editra based on object ids                    #
 # Author: Cody Precord <cprecord@editra.org>                                  #
 # Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
-#--------------------------------------------------------------------------#
-# FILE: ed_art.py                                                          #
-# AUTHOR: Cody Precord                                                     #
-# LANGUAGE: Python                                                         #
-# SUMMARY:                                                                 #
-#  Provides and ArtProvider class that works off of object ID's to return  #
-# an associated art resource. The provider works hand in hand with Editra's#
-# theme framework that allows for themes to be provided as plugins that    #
-# act as the resource providers for the ArtProvider.                       #
-#                                                                          #
-#--------------------------------------------------------------------------#
+Provides and ArtProvider class that works off of object ID's to return an
+associated art resource. The provider works hand in hand with Editra's theme
+framework that allows for themes to be provided as plugins that act as the
+resource providers for the ArtProvider.
+
+@summary: Editra's ArtProvider, supplies icons based off of object ids
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: ed_art.py 51382 2008-01-26 04:30:54Z CJP $"
-__revision__ = "$Revision: 51382 $"
+__cvsid__ = "$Id: ed_art.py 52855 2008-03-27 14:53:06Z CJP $"
+__revision__ = "$Revision: 52855 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -36,7 +32,8 @@ import ed_theme
 #--------------------------------------------------------------------------#
 
 # Map for default system/wx provided graphic resources.
-DEFAULT = { 
+# For toolbar ones fall back to ones provided by the default Tango theme
+DEFAULT = {
             ed_glob.ID_ADD_BM  : wx.ART_ADD_BOOKMARK,
             ed_glob.ID_BIN_FILE : wx.ART_EXECUTABLE_FILE,
             ed_glob.ID_CDROM   : wx.ART_CDROM,
@@ -44,7 +41,7 @@ DEFAULT = {
             ed_glob.ID_CUT     : wx.ART_CUT,
             ed_glob.ID_DELETE  : wx.ART_DELETE,
             ed_glob.ID_DEL_BM  : wx.ART_DEL_BOOKMARK,
-            ed_glob.ID_DOCPROP : wx.ART_NORMAL_FILE,        # Bad match
+#            ed_glob.ID_DOCPROP : wx.ART_NORMAL_FILE,        # Bad match
             ed_glob.ID_DOWN    : wx.ART_GO_DOWN,
             ed_glob.ID_EXIT    : wx.ART_QUIT,
             ed_glob.ID_FILE    : wx.ART_NORMAL_FILE,
@@ -56,29 +53,29 @@ DEFAULT = {
             ed_glob.ID_NEW     : wx.ART_NEW,
             ed_glob.ID_NEXT_MARK : wx.ART_GO_FORWARD,
             ed_glob.ID_OPEN    : wx.ART_FILE_OPEN,
-            ed_glob.ID_PACKAGE : wx.ART_HARDDISK,           # Poor match
+#            ed_glob.ID_PACKAGE : wx.ART_HARDDISK,           # Poor match
             ed_glob.ID_PASTE   : wx.ART_PASTE,
-            ed_glob.ID_PREF    : wx.ART_EXECUTABLE_FILE,    # Bad match
+#            ed_glob.ID_PREF    : wx.ART_EXECUTABLE_FILE,    # Bad match
             ed_glob.ID_PRE_MARK : wx.ART_GO_BACK,
             ed_glob.ID_PRINT   : wx.ART_PRINT,
             ed_glob.ID_REDO    : wx.ART_REDO,
             ed_glob.ID_SAVE    : wx.ART_FILE_SAVE,
             ed_glob.ID_SAVEAS  : wx.ART_FILE_SAVE_AS,
             ed_glob.ID_STOP    : wx.ART_ERROR,
-            ed_glob.ID_THEME   : wx.ART_INFORMATION,   # Bad match
+#            ed_glob.ID_THEME   : wx.ART_INFORMATION,   # Bad match
             ed_glob.ID_UNDO    : wx.ART_UNDO,
             ed_glob.ID_UP      : wx.ART_GO_UP,
             ed_glob.ID_USB     : wx.ART_REMOVABLE,
-            ed_glob.ID_WEB     : wx.ART_HARDDISK       # Bad match
+#            ed_glob.ID_WEB     : wx.ART_HARDDISK       # Bad match
 }
 
 #--------------------------------------------------------------------------#
 
 class EditraArt(wx.ArtProvider):
-    """Editras Art Provider. Provides the mimetype images and loads any custom 
+    """Editras Art Provider. Provides the mimetype images and loads any custom
     user defined icon sets as well. Editra theme specific icons are looked up
     by passing an objects related id as a string to this providers CreateBitmap
-    function for it to talk to the theme resource provider. If the id is not 
+    function for it to talk to the theme resource provider. If the id is not
     a defined object ID it is simply ignored or passed to the the next
     ArtProvider in the chain to handle.
 
@@ -140,7 +137,7 @@ class EditraArt(wx.ArtProvider):
         elif art_id in syntax.SyntaxIds():
             # Dont fail when requesting mime type icons, fallback to the system
             # icon for a normal file in this case.
-            bmp = wx.ArtProvider.GetBitmap(wx.ART_NORMAL_FILE, 
+            bmp = wx.ArtProvider.GetBitmap(wx.ART_NORMAL_FILE,
                                            wx.ART_MENU, (16, 16))
 
         if bmp.IsOk() and not bmp.IsNull():
