@@ -18,8 +18,8 @@ a gradient using system defined colors.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_cmdbar.py 53240 2008-04-17 03:57:49Z CJP $"
-__revision__ = "$Revision: 53240 $"
+__svnid__ = "$Id: ed_cmdbar.py 53692 2008-05-21 22:01:00Z CJP $"
+__revision__ = "$Revision: 53692 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -107,7 +107,11 @@ class CommandBar(wx.Panel):
 
         # Bind Events
         ed_msg.Subscribe(self.OnThemeChange, ed_msg.EDMSG_THEME_CHANGED)
-        self.Bind(wx.EVT_PAINT, self.OnPaint)
+
+        # Don't paint the gradient on gtk due to transparency
+        # issues with some controls
+        if wx.Platform != '__WXGTK__':
+            self.Bind(wx.EVT_PAINT, self.OnPaint)
         self.Bind(wx.EVT_BUTTON, self.OnButton)
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
 
