@@ -15,8 +15,8 @@ main Ui component of the editor that contains all the other components.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 53301 2008-04-22 03:37:58Z CJP $"
-__revision__ = "$Revision: 53301 $"
+__svnid__ = "$Id: ed_main.py 54034 2008-06-08 22:38:08Z CJP $"
+__revision__ = "$Revision: 54034 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -32,6 +32,7 @@ import util
 import profiler
 import ed_toolbar
 import ed_event
+import ed_msg
 import ed_pages
 import ed_menu
 import ed_print
@@ -89,6 +90,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         #---- Status bar on bottom of window ----#
         self.SetStatusBar(ed_statbar.EdStatBar(self))
+        self.GetStatusBar().Show(_PGET('STATBAR', default=True))
 
         #---- End Statusbar Setup ----#
 
@@ -163,6 +165,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                        # View Menu
                                        (ID_GOTO_LINE, self.OnCommandBar),
                                        (ID_GOTO_MBRACE, self.DispatchToControl),
+                                       (ID_SHOW_SB, self.OnShowStatusBar),
                                        (ID_VIEW_TOOL, self.OnViewTb),
 
                                        # Format Menu
@@ -217,6 +220,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                      (ID_ZOOM_OUT, self.OnUpdateViewUI),
                                      (ID_GOTO_MBRACE, self.OnUpdateViewUI),
                                      (ID_HLCARET_LINE, self.OnUpdateViewUI),
+                                     (ID_SHOW_SB, self.OnUpdateViewUI),
                                      (ID_VIEW_TOOL, self.OnUpdateViewUI),
                                      (ID_SHOW_WS, self.OnUpdateViewUI),
                                      (ID_SHOW_EDGE, self.OnUpdateViewUI),
@@ -265,9 +269,11 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self.LOG("[ed_main][info] Loading Generator plugins")
         generator.Generator(plgmgr).InstallMenu(menbar.GetMenuByName("tools"))
 
-        # Set Perspective
+        # Set Perspective and other UI settings
         self.SetPerspective(_PGET('DEFAULT_VIEW'))
         self._mgr.Update()
+        ed_msg.PostMessage(ed_msg.EDMSG_DSP_FONT,
+                           _PGET('FONT3', 'font', wx.NORMAL_FONT))
 
     __name__ = u"MainWindow"
 
@@ -321,6 +327,32 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             if hasattr(win, 'filehistory'):
                 win.filehistory.AddFileToHistory(fname)
 
+    def AddMenuHandler(self, menu_id, handler):
+        """Add a menu event handler to the handler stack
+        @param menu_id: Menu item id
+        @param handler: Handler callable
+        @postcondition: handler is added only if its not already in the set
+
+        """
+        for item in self._handlers['menu']:
+            if item[0] == menu_id:
+                return
+        else:
+            self._handlers['menu'].append((menu_id, handler))
+
+    def AddUIHandler(self, menu_id, handler):
+        """Add a UpdateUI event handler to the handler stack
+        @param menu_id: Menu item id
+        @param handler: Handler callable
+        @postcondition: handler is added only if its not already in the set
+
+        """
+        for item in self._handlers['ui']:
+            if item[0] == menu_id:
+                return
+        else:
+            self._handlers['ui'].append((menu_id, handler))
+
     def DoOpen(self, evt, fname=u''):
         """ Do the work of opening a file and placing it
         in a new notebook page.
@@ -476,14 +508,16 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         e_id = evt.GetId()
         ctrls = list()
         if e_id == ID_SAVE:
-            ctrls = [(self.nb.GetPageText(self.nb.GetSelection()),
-                     self.nb.GetCurrentCtrl())]
+            page = self.nb.GetSelection()
+            ctrls = [(self.nb.GetPageText(page),
+                      self.nb.GetCurrentCtrl(), page)]
         elif e_id == ID_SAVEALL:
+            # Collect all open editor buffers
             for page in xrange(self.nb.GetPageCount()):
                 if issubclass(self.nb.GetPage(page).__class__,
                                            wx.stc.StyledTextCtrl):
                     ctrls.append((self.nb.GetPageText(page),
-                                  self.nb.GetPage(page)))
+                                  self.nb.GetPage(page), page))
         else:
             evt.Skip()
             return
@@ -495,6 +529,11 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 result = ctrl[1].SaveFile(fpath)
                 if result:
                     self.PushStatusText(_("Saved File: %s") % fname, SB_INFO)
+                    if e_id == ID_SAVEALL:
+                        if ctrl[2] != self.nb.GetSelection():
+                            self.nb.SetPageText(ctrl[2], fname)
+                        else:
+                            self.nb.OnUpdatePageText(None)
                 else:
                     err = ctrl[1].GetDocument().GetLastError()
                     self.PushStatusText(_("ERROR: %s") % err, SB_INFO)
@@ -511,7 +550,13 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @type evt: wxMenuEvent
 
         """
-        dlg = wx.FileDialog(self, _("Choose a Save Location"), '',
+        if page:
+            ctrl = page
+        else:
+            ctrl = self.nb.GetCurrentCtrl()
+
+        dlg = wx.FileDialog(self, _("Choose a Save Location"),
+                            os.path.dirname(ctrl.GetFileName()),
                             title.lstrip("*"),
                             ''.join(syntax.GenFileFilters()),
                             wx.SAVE | wx.OVERWRITE_PROMPT)
@@ -520,11 +565,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             path = dlg.GetPath()
             dlg.Destroy()
 
-            if page:
-                ctrl = page
-            else:
-                ctrl = self.nb.GetCurrentCtrl()
-
             result = ctrl.SaveFile(path)
             fname = util.GetFileName(ctrl.GetFileName())
             if not result:
@@ -714,6 +754,19 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
     #---- End File Menu Functions ----#
 
     #---- View Menu Functions ----#
+    def OnShowStatusBar(self, evt):
+        """Toggles visibility of status bar
+        @param evt: wxMenuEvent
+
+        """
+        if evt.GetId() == ID_SHOW_SB:
+            show = not self.GetStatusBar().IsShown()
+            _PSET('STATBAR', show)
+            self.GetStatusBar().Show(show)
+            self.SendSizeEvent()
+        else:
+            evt.Skip()
+
     def OnViewTb(self, evt):
         """Toggles visibility of toolbar
         @param evt: Event fired that called this handler
@@ -996,6 +1049,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             evt.Enable(-1 not in ctrl.GetBracePair())
         elif e_id == ID_HLCARET_LINE:
             evt.Check(ctrl.GetCaretLineVisible())
+        elif e_id == ID_SHOW_SB:
+            evt.Check(self.GetStatusBar().IsShown())
         elif e_id == ID_VIEW_TOOL:
             evt.Check(self.GetToolBar().IsShown())
         elif e_id == ID_SHOW_WS:
