@@ -20,8 +20,8 @@ in the notebook see ed_stc.py
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 53350 2008-04-25 16:50:08Z CJP $"
-__revision__ = "$Revision: 53350 $"
+__svnid__ = "$Id: ed_pages.py 54023 2008-06-08 01:14:19Z CJP $"
+__revision__ = "$Revision: 54023 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -504,7 +504,6 @@ class EdPages(FNB.FlatNotebook):
         if fname == "":
             fname = self.GetPageText(pgid)
         self.frame.SetTitle("%s - file://%s" % (util.GetFileName(fname), fname))
-        ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CHANGED, (self, pgid))
 
     def OnPageChanged(self, evt):
         """Actions to do after a page change
@@ -519,6 +518,7 @@ class EdPages(FNB.FlatNotebook):
         self.LOG("[ed_pages][info] It has file named: %s" % \
                  self.control.GetFileName())
         self.control.PostPositionEvent()
+        ed_msg.PostMessage(ed_msg.EDMSG_UI_NB_CHANGED, (self, cpage))
 
     def OnPageClosing(self, evt):
         """Checks page status to flag warnings before closing
@@ -640,7 +640,7 @@ class EdPages(FNB.FlatNotebook):
     def OnUpdatePageText(self, evt):
         """Update the title text of the current page
         @param evt: event that called this handler
-        @type evt: stc.EVT_STC_MODIFY
+        @type evt: stc.EVT_STC_MODIFY (unused)
         @note: this method must complete its work very fast it gets
                called everytime a character is entered or removed from
                the document.
