@@ -2,7 +2,7 @@
 # Name: ed_search.py                                                          #
 # Purpose: Text searching services and utilities                              #
 # Author: Cody Precord <cprecord@editra.org>                                  #
-# Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
+# Copyright: (c) 2007,2008 Cody Precord <staff@editra.org>                    #
 # License: wxWindows License                                                  #
 ###############################################################################
 
@@ -14,8 +14,8 @@ highlight text in a StyledTextCtrl.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_search.py 52855 2008-03-27 14:53:06Z CJP $"
-__revision__ = "$Revision: 52855 $"
+__svnid__ = "$Id: ed_search.py 53600 2008-05-15 18:27:38Z CJP $"
+__revision__ = "$Revision: 53600 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -108,6 +108,7 @@ class TextFinder(object):
                 # HACK to ensure selection is visible
                 sel = pool.GetSelection()
                 pool.SetSelection(sel[1], sel[0])
+                pool.EnsureVisible(pool.LineFromPosition(found))
             else:
                 # Try search from begining/end again
                 self.SetStart(pool)
@@ -150,15 +151,20 @@ class TextFinder(object):
             self.SetScroll(pool) # Save scroll pos
             pool.SetTargetStart(0)
             pool.SetTargetEnd(pool.GetLength())
-            pool.SetSearchFlags(flag_map[s_flags - wx.FR_DOWN] | \
+            pool.SetSearchFlags(flag_map[max(0, s_flags - wx.FR_DOWN)] | \
                                 wx.stc.STC_FIND_REGEXP)
             replaced = 0
+            fail = 0
             pool.BeginUndoAction()
-            while pool.SearchInTarget(query) > 0:
-                pool.SetSelection(pool.GetTargetStart(), pool.GetTargetEnd())
-                pool.ReplaceSelection(replacestring)
+            while fail < 2: #pool.SearchInTarget(query) > 0:
+                # HACK if the search pattern is at the begining of the buffer
+                #      the search will fail the first time. So check twice
+                #      before giving up. ?Scintilla Bug?
+                if pool.SearchInTarget(query) < 0:
+                    fail += 1
+                    continue
+                pool.ReplaceTarget(replacestring)
                 replaced += 1
-                pool.SetTargetStart(pool.GetTargetStart() + len(replacestring))
                 pool.SetTargetEnd(pool.GetLength())
             pool.EndUndoAction()
 
