@@ -18,15 +18,17 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 53301 2008-04-22 03:37:58Z CJP $"
-__revision__ = "$Revision: 53301 $"
+__svnid__ = "$Id: ed_stc.py 53882 2008-05-31 20:03:29Z CJP $"
+__revision__ = "$Revision: 53882 $"
 
 #-------------------------------------------------------------------------#
-# Dependencies
+# Imports
 
 import os
 import re
 import wx, wx.stc
+
+# Local Imports
 import ed_event
 import ed_glob
 from profiler import Profile_Get as _PGET
@@ -36,6 +38,7 @@ import util
 import ed_style
 import ed_msg
 import ed_txt
+import ed_menu
 from ed_keyh import KeyHandler, ViKeyHandler
 
 #-------------------------------------------------------------------------#
@@ -130,6 +133,9 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.Configure()
         self.UpdateBaseStyles()
 
+        # Other Settings
+        self.UsePopUp(False)
+
         #self.Bind(wx.stc.EVT_STC_MACRORECORD, self.OnRecordMacro)
         self.Bind(wx.stc.EVT_STC_MARGINCLICK, self.OnMarginClick)
         self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnModified)
@@ -138,6 +144,15 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.Bind(wx.EVT_KEY_UP, self.OnKeyUp)
         self.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
 
+        # Context Menu Events
+        self.Bind(wx.EVT_CONTEXT_MENU, self.OnContextMenu)
+        self.Bind(wx.EVT_MENU, lambda evt: self.Undo(), id=wx.ID_UNDO)
+        self.Bind(wx.EVT_MENU, lambda evt: self.Redo(), id=wx.ID_REDO)
+        self.Bind(wx.EVT_MENU, lambda evt: self.Cut(), id=wx.ID_CUT)
+        self.Bind(wx.EVT_MENU, lambda evt: self.Copy(), id=wx.ID_COPY)
+        self.Bind(wx.EVT_MENU, lambda evt: self.Paste(), id=wx.ID_PASTE)
+        self.Bind(wx.EVT_MENU, lambda evt: self.SelectAll(), id=wx.ID_SELECTALL)
+
        #---- End Init ----#
 
     __name__ = u"EditraTextCtrl"
@@ -336,6 +351,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @postcondition: all profile dependant attributes are configured
 
         """
+#        self.SetControlCharSymbol(172)
         self.SetWrapMode(_PGET('WRAP', 'bool'))
         self.SetViewWhiteSpace(_PGET('SHOW_WS', 'bool'))
         self.SetUseAntiAliasing(_PGET('AALIASING'))
@@ -406,6 +422,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                         nchars = nchars - len(self._code['comment'][1])
                     self.GotoPos(sel[0] + nchars)
 
+    def CanCopy(self):
+        """Check if copy/cut is possible"""
+        return self.GetSelectionStart() != self.GetSelectionEnd()
+
     def ConvertCase(self, upper=False):
         """Converts the case of the selected text to either all lower
         case(default) or all upper case.
@@ -633,6 +653,13 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             style = (_PGET('SYNTHEME', 'str') + u".ess").lower()
         else:
             style = _PGET('SYNTHEME', 'str').lower()
+
+        # Get Correct Filename if it exists
+        for sheet in util.GetResourceFiles('styles', False, True, title=False):
+            if sheet.lower() == style.lower():
+                style = sheet
+                break
+
         user = os.path.join(ed_glob.CONFIG['STYLES_DIR'], style)
         sysp = os.path.join(ed_glob.CONFIG['SYS_STYLES_DIR'], style)
         if os.path.exists(user):
@@ -685,11 +712,14 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         key_code = evt.GetKeyCode()
+        cpos = self.GetCurrentPos()
         if self.key_handler.ProcessKey(key_code):
             # The key handler handled this keypress, we don't need to insert
             # the character into the buffer.
             pass
-        elif not self._config['autocomp']:
+        elif not self._config['autocomp'] or \
+             self.IsString(cpos) or \
+             self.IsComment(cpos):
             evt.Skip()
             return
         elif key_code in self._code['compsvc'].GetAutoCompKeys():
@@ -710,6 +740,22 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             evt.Skip()
         return
 
+    def OnContextMenu(self, evt):
+        """Show the right click context menu
+        @param evt: EVT_CONTEXT_MENU
+
+        """
+        menu = ed_menu.EdMenu()
+        menu.Append(wx.ID_UNDO, _("Undo"))
+        menu.Append(wx.ID_REDO, _("Redo"))
+        menu.AppendSeparator()
+        menu.Append(wx.ID_CUT, _("Cut"))
+        menu.Append(wx.ID_COPY, _("Copy"))
+        menu.Append(wx.ID_PASTE, _("Paste"))
+        menu.AppendSeparator()
+        menu.Append(wx.ID_SELECTALL, _("Select All"))
+        self.PopupMenu(menu)
+
     def OnKeyUp(self, evt):
         """Update status bar of window
         @param evt: wxEVT_KEY_UP
@@ -879,25 +925,34 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         if evt.GetMargin() == FOLD_MARGIN:
-            if evt.GetShift() and evt.GetControl():
+            if evt.GetShift() and \
+               (evt.GetControl() or (wx.Platform == '__WXMAC__' and evt.GetAlt())):
                 self.FoldAll()
             else:
                 line_clicked = self.LineFromPosition(evt.GetPosition())
-                if self.GetFoldLevel(line_clicked) & \
-                   wx.stc.STC_FOLDLEVELHEADERFLAG:
+                level = self.GetFoldLevel(line_clicked)
+                if level & wx.stc.STC_FOLDLEVELHEADERFLAG:
+
+                    # Expand node and all Subnodes
                     if evt.GetShift():
                         self.SetFoldExpanded(line_clicked, True)
-                        self.Expand(line_clicked, True, True, 1)
-                    elif evt.GetControl():
+                        self.Expand(line_clicked, True, True, 100, level)
+                    elif evt.GetControl() or \
+                        (wx.Platform == '__WXMAC__' and evt.GetAlt()):
+                        # Contract all subnodes of clicked one
+                        # Note: using Alt as Ctrl can not be recieved for
+                        # clicks on mac (Scintilla Bug).
                         if self.GetFoldExpanded(line_clicked):
                             self.SetFoldExpanded(line_clicked, False)
-                            self.Expand(line_clicked, False, True, 0)
+                            self.Expand(line_clicked, False, True, 0, level)
                         else:
+                            # Expand all subnodes
                             self.SetFoldExpanded(line_clicked, True)
-                            self.Expand(line_clicked, True, True, 100)
+                            self.Expand(line_clicked, True, True, 100, level)
                     else:
                         self.ToggleFold(line_clicked)
         elif evt.GetMargin() == MARK_MARGIN:
+            # Bookmarks ect...
             line_clicked = self.LineFromPosition(evt.GetPosition())
             if self.MarkerGet(line_clicked):
                 self.MarkerDelete(line_clicked, MARK_MARGIN)
@@ -946,10 +1001,13 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         line = line + 1
 
         while line <= last_child:
-            if force and not (vis_levels > 0):
-                self.HideLines(line, line)
+            if force:
+                if vis_levels > 0:
+                    self.ShowLines(line, line)
+                else:
+                    self.HideLines(line, line)
             else:
-                if do_expand or vis_levels > 0:
+                if do_expand:
                     self.ShowLines(line, line)
 
             if level == -1:
@@ -960,10 +1018,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                     self.SetFoldExpanded(line, vis_levels > 1)
                     line = self.Expand(line, do_expand, force, vis_levels - 1)
                 else:
-                    if do_expand and self.GetFoldExpanded(line):
-                        line = self.Expand(line, True, force, vis_levels - 1)
-                    else:
-                        line = self.Expand(line, False, force, vis_levels - 1)
+                    if do_expand:
+                        if self.GetFoldExpanded(line):
+                            self.SetFoldExpanded(line, True)
+                    line = self.Expand(line, do_expand, force, vis_levels - 1)
             else:
                 line = line + 1
         return line
@@ -1234,6 +1292,14 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         return self._config['brackethl']
 
+    def IsComment(self, pos):
+        """Is the given position in a comment region of the current buffer
+        @param pos: int position in buffer
+        @return: bool
+
+        """
+        return 'comment' in self.FindTagById(self.GetStyleAt(pos))
+
     def IsFoldingOn(self):
         """Returns whether code folding is being used by this
         control or not.
@@ -1258,6 +1324,15 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         return self.recording
 
+    def IsString(self, pos):
+        """Is the given position in a string region of the current buffer
+        @param pos: int position in buffer
+        @return: bool
+
+        """
+        style = self.GetStyleAt(pos)
+        return self.FindTagById(style) in ('string_style', 'char_style')
+
     def LinesJoin(self):
         """Join lines in target and compress whitespace
         @note: overrides default function to allow for leading
@@ -1782,6 +1857,9 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.SetProperties(props)
         # Set Comment Pattern
         self._code['comment'] = comment
+
+        # Notify that lexer has changed
+        ed_msg.PostMessage(ed_msg.EDMSG_UI_STC_LEXER)
         return True
 
     def SetKeyWords(self, kw_lst):
