@@ -60,8 +60,8 @@ memory is not likely to be very large.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: plugin.py 52855 2008-03-27 14:53:06Z CJP $"
-__revision__ = "$Revision: 52855 $"
+__svnid__ = "$Id: plugin.py 54026 2008-06-08 02:16:56Z CJP $"
+__revision__ = "$Revision: 54026 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -216,6 +216,14 @@ class Plugin(object):
         """
         pass
 
+    def IsInstalled(self):
+        """Return whether the plugins L{InstallHook} method has been called
+        or not already.
+        @return: bool
+
+        """
+        return False
+
 #-----------------------------------------------------------------------------#
 
 class PluginData(object):
