@@ -12,8 +12,8 @@ This file contains various helper functions and utilities that the program uses.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 52888 2008-03-28 02:16:54Z CJP $"
-__revision__ = "$Revision: 52888 $"
+__svnid__ = "$Id: util.py 53584 2008-05-13 00:10:32Z CJP $"
+__revision__ = "$Revision: 53584 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -369,7 +369,7 @@ def GetFileManagerCmd():
     """Get the file manager open command for the current os. Under linux
     it will check for nautilus and konqueror and return which one it finds
     first or 'nautilus' (Gnome) if it finds neither.
-    @return: string command
+    @return: string
 
     """
     if wx.Platform == '__WXMAC__':
@@ -377,7 +377,9 @@ def GetFileManagerCmd():
     elif wx.Platform == '__WXMSW__':
         return 'explorer'
     else:
-        for cmd in ('nautilus', 'konqueror'):
+        # Check for common linux filemanagers returning first one found
+        #          Gnome/ubuntu KDE/kubuntu  xubuntu
+        for cmd in ('nautilus', 'konqueror', 'Thunar'):
             result = os.system("which %s > /dev/null" % cmd)
             if result == 0:
                 return cmd
